import twilio from 'twilio';
import { config } from '@/utils/config';
import logger from '@/utils/logger';

class WhatsAppService {
  private client: twilio.Twilio | null = null;

  constructor() {
    if (config.twilio.accountSid && config.twilio.authToken) {
      this.client = twilio(config.twilio.accountSid, config.twilio.authToken);
    } else {
      logger.warn('Twilio credentials not configured. WhatsApp functionality disabled.');
    }
  }

  async sendMessage(toNumber: string, message: string): Promise<boolean> {
    if (!this.client) {
      logger.error('WhatsApp service not configured');
      return false;
    }

    try {
      const formattedNumber = toNumber.startsWith('whatsapp:') ? toNumber : `whatsapp:${toNumber}`;

      const messageResponse = await this.client.messages.create({
        body: message,
        from: config.twilio.whatsappFrom,
        to: formattedNumber,
      });

      logger.info(`WhatsApp message sent successfully. SID: ${messageResponse.sid}`);
      return true;
    } catch (error) {
      logger.error('Failed to send WhatsApp message:', error);
      return false;
    }
  }
}

const whatsappService = new WhatsAppService();

export const sendTaskReminder = async (phoneNumber: string, task: any): Promise<boolean> => {
  const dueInfo = task.dueDate ? ` (Due: ${new Date(task.dueDate).toLocaleDateString()})` : '';
  const message = `🔔 Task Reminder: ${task.title}\n\n${task.description || 'No description provided'}${dueInfo}\n\nPriority: ${task.priority}`;
  
  return whatsappService.sendMessage(phoneNumber, message);
};

export const sendTaskCompletion = async (phoneNumber: string, task: any): Promise<boolean> => {
  const message = `✅ Task Completed: ${task.title}\n\nCongratulations! You've successfully completed this task.`;
  
  return whatsappService.sendMessage(phoneNumber, message);
};

export const sendTaskOverdue = async (phoneNumber: string, task: any): Promise<boolean> => {
  const message = `⚠️ Task Overdue: ${task.title}\n\nThis task is overdue. Please complete it as soon as possible.\n\nPriority: ${task.priority}`;
  
  return whatsappService.sendMessage(phoneNumber, message);
};

export default whatsappService;